const express = require("express")
const session = require("express-session")
const app = express()
const testRoutes = require("./routes/testRoutes")
const authRoutes = require("./routes/authRoutes")
const testResultRoutes = require("./routes/testResultRoutes")
const testCaseRoutes = require("./routes/testCaseRoutes")
const infoRoutes = require("./routes/infoRoutes")
const path = require("path")

app.use(express.urlencoded({ extended: true }))
app.use(express.json())
app.use(
  session({
    secret: process.env.SESSION_SECRET || "your-secret-key", // Ideally use environment variable
    resave: false,
    saveUninitialized: true,
  }),
)

app.set("views", path.join(__dirname, "views")) // Set views directory
app.set("view engine", "ejs") // Set view engine to ejs

// Serve static files
app.use(express.static(path.join(__dirname, "public")))

// Root route redirects to login
app.get("/", (req, res) => {
  res.redirect("/login")
})

// Routes
app.use("/tests", testRoutes)
app.use("/", authRoutes)
app.use("/testresults", testResultRoutes)
app.use("/testcases", testCaseRoutes)
app.use("/more-info", infoRoutes)

app.listen(3000, () => {
  console.log("Server running on port 3000")
})

