const bcrypt = require("bcrypt")
const User = require("../models/userModel")

exports.login = async (req, res) => {
  const { email, password } = req.body
  try {
    const user = await User.getUserByEmail(email)
    if (!user) {
      return res.render("login", { error: "Invalid credentials" })
    }

    const isPasswordValid = await bcrypt.compare(password, user.password)
    if (isPasswordValid) {
      req.session.userId = user.id
      return res.redirect("/dashboard")
    } else {
      return res.render("login", { error: "Invalid credentials" })
    }
  } catch (err) {
    console.error(err)
    res.status(500).render("login", { error: "Server error" })
  }
}

exports.logout = (req, res) => {
  req.session.destroy(() => {
    res.redirect("/login")
  })
}

exports.renderLogin = (req, res) => {
  res.render("login", { error: null })
}

exports.renderRegister = (req, res) => {
  res.render("register", { error: null })
}

exports.register = async (req, res) => {
  const { username, email, password, confirmPassword } = req.body

  try {
    // Validate input
    if (!username || !email || !password || !confirmPassword) {
      return res.render("register", { error: "All fields are required" })
    }

    if (password !== confirmPassword) {
      return res.render("register", { error: "Passwords do not match" })
    }

    // Check if user already exists
    const existingUser = await User.getUserByEmail(email)
    if (existingUser) {
      return res.render("register", { error: "Email already in use" })
    }

    const existingUsername = await User.getUserByUsername(username)
    if (existingUsername) {
      return res.render("register", { error: "Username already taken" })
    }

    // Hash password
    const saltRounds = 10
    const hashedPassword = await bcrypt.hash(password, saltRounds)

    // Create user
    await User.createUser(username, email, hashedPassword)

    // Redirect to login
    res.render("login", { error: "Registration successful! Please login." })
  } catch (err) {
    console.error(err)
    res.status(500).render("register", { error: "Server error during registration" })
  }
}

exports.renderDashboard = (req, res) => {
  res.render("dashboard")
}

