const TestCase = require("../models/testCaseModel")
const Test = require("../models/testModel")

exports.getAllTestCases = async (req, res) => {
  try {
    const testCases = await TestCase.getAllTestCases()
    const tests = await Test.getAllTests()
    res.render("testCase/listTestCases", { 
      testCases, 
      tests,
      error: null,
      selectedTest: null,
      selectedStatus: null,
      selectedFramework: null
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testCase/listTestCases", { 
      testCases: [], 
      tests: [],
      error: "Failed to fetch test cases" 
    })
  }
}

exports.getTestCaseById = async (req, res) => {
  const id = req.params.id
  try {
    const testCase = await TestCase.getTestCaseById(id)
    const tests = await Test.getAllTests()
    if (!testCase) {
      return res.status(404).render("error", { message: "Test case not found" })
    }
    res.render("testCase/editTestCase", { testCase, tests, error: null })
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

exports.createTestCase = async (req, res) => {
  try {
    // Add user_id from session to the test case data
    const testCaseData = {
      ...req.body,
      user_id: req.session.userId,
    }

    await TestCase.createTestCase(testCaseData)
    res.redirect("/testcases")
  } catch (err) {
    console.error(err)
    const tests = await Test.getAllTests()
    res.status(500).render("testCase/addTestCase", { error: "Failed to create test case", tests })
  }
}

exports.updateTestCase = async (req, res) => {
  const id = req.params.id
  try {
    const result = await TestCase.updateTestCase(id, req.body)
    if (result.affectedRows === 0) {
      return res.status(404).render("error", { message: "Test case not found" })
    }
    res.redirect("/testcases")
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

exports.deleteTestCase = async (req, res) => {
  const id = req.params.id
  try {
    const result = await TestCase.deleteTestCase(id)
    if (result.affectedRows === 0) {
      return res.status(404).render("error", { message: "Test case not found" })
    }
    res.redirect("/testcases")
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

exports.searchTestCases = async (req, res) => {
  const searchTerm = req.query.searchTerm || ""
  try {
    const testCases = await TestCase.searchTestCases(searchTerm)
    const tests = await Test.getAllTests()
    res.render("testCase/listTestCases", { 
      testCases, 
      tests,
      error: null,
      selectedTest: null,
      selectedStatus: null,
      selectedFramework: null
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testCase/listTestCases", { 
      testCases: [], 
      tests: [],
      error: "Failed to search test cases" 
    })
  }
}

exports.getTestCasesByFramework = async (req, res) => {
  const framework = req.query.framework || ""
  try {
    const testCases = await TestCase.getTestCasesByFramework(framework)
    const tests = await Test.getAllTests()
    res.render("testCase/listTestCases", { 
      testCases, 
      tests,
      error: null,
      selectedTest: null,
      selectedStatus: null,
      selectedFramework: framework 
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testCase/listTestCases", {
      testCases: [],
      tests: [],
      error: "Failed to fetch test cases",
      selectedFramework: framework,
    })
  }
}

exports.getTestCasesByStatus = async (req, res) => {
  const status = req.query.status || ""
  try {
    const testCases = await TestCase.getTestCasesByStatus(status)
    const tests = await Test.getAllTests()
    res.render("testCase/listTestCases", { 
      testCases, 
      tests,
      error: null,
      selectedTest: null,
      selectedStatus: status,
      selectedFramework: null
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testCase/listTestCases", {
      testCases: [],
      tests: [],
      error: "Failed to fetch test cases",
      selectedStatus: status,
    })
  }
}

exports.getTestCasesByTest = async (req, res) => {
  const testId = req.query.testId || ""
  try {
    const testCases = await TestCase.getTestCasesByTestId(testId)
    const tests = await Test.getAllTests()
    res.render("testCase/listTestCases", { 
      testCases, 
      tests,
      error: null,
      selectedTest: testId,
      selectedStatus: null,
      selectedFramework: null
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testCase/listTestCases", {
      testCases: [],
      tests: [],
      error: "Failed to fetch test cases",
      selectedTest: testId,
    })
  }
}

exports.renderAddTestCase = async (req, res) => {
  try {
    const tests = await Test.getAllTests()
    res.render("testCase/addTestCase", { error: null, tests })
  } catch (err) {
    console.error(err)
    res.status(500).render("testCase/addTestCase", { error: "Failed to load form data", tests: [] })
  }
}

