const Test = require("../models/testModel")

exports.getAllTests = async (req, res) => {
  try {
    const tests = await Test.getAllTests()
    res.render("test/listTests", { tests, error: null })
  } catch (err) {
    console.error(err)
    res.status(500).render("test/listTests", { tests: [], error: "Failed to fetch tests" })
  }
}

exports.getTestById = async (req, res) => {
  const id = req.params.id
  try {
    const test = await Test.getTestById(id)
    if (!test) {
      return res.status(404).render("error", { message: "Test not found" })
    }
    res.render("test/editTest", { test, error: null })
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

exports.createTest = async (req, res) => {
  const { test_name, description } = req.body
  try {
    await Test.createTest(test_name, description)
    res.redirect("/tests")
  } catch (err) {
    console.error(err)
    res.status(500).render("test/addTest", { error: "Failed to create test" })
  }
}

exports.updateTest = async (req, res) => {
  const { test_name, description } = req.body
  const id = req.params.id
  try {
    const result = await Test.updateTest(id, test_name, description)
    if (result.affectedRows === 0) {
      return res.status(404).render("error", { message: "Test not found" })
    }
    res.redirect("/tests")
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

exports.deleteTest = async (req, res) => {
  const id = req.params.id
  try {
    const result = await Test.deleteTest(id)
    if (result.affectedRows === 0) {
      return res.status(404).render("error", { message: "Test not found" })
    }
    res.redirect("/tests")
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

exports.searchTests = async (req, res) => {
  const searchTerm = req.query.searchTerm || ""
  try {
    const tests = await Test.searchTests(searchTerm)
    res.render("test/listTests", { tests, error: null })
  } catch (err) {
    console.error(err)
    res.status(500).render("test/listTests", { tests: [], error: "Failed to search tests" })
  }
}

exports.renderAddTest = (req, res) => {
  res.render("test/addTest", { error: null })
}

exports.getTestCases = async (req, res) => {
  const testId = req.params.id
  try {
    const test = await Test.getTestById(testId)
    if (!test) {
      return res.status(404).render("error", { message: "Test not found" })
    }
    const testCases = await Test.getTestCasesByTestId(testId)
    res.render("test/testCases", { test, testCases, error: null })
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Server error" })
  }
}

