const TestResult = require("../models/testResultModel")
const db = require("../config/db")

exports.getAllTestResults = async (req, res) => {
  try {
    const testStatistics = await TestResult.getTestStatistics()
    const statusStats = await TestResult.getTestCasesByStatus()
    const frameworkStats = await TestResult.getTestCasesByFramework()

    res.render("testResult/listTestResults", {
      testStatistics,
      statusStats,
      frameworkStats,
      error: null
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testResult/listTestResults", {
      testStatistics: [],
      statusStats: [],
      frameworkStats: [],
      error: "Failed to fetch test statistics"
    })
  }
}

exports.addTestResult = async (req, res) => {
  const { test_id, user_id, result, score } = req.body
  try {
    await TestResult.addTestResult(test_id, user_id, result, score)
    res.redirect("/testresults")
  } catch (err) {
    console.error(err)
    res.status(500).render("error", { message: "Failed to add test result" })
  }
}

exports.renderAddTestResult = async (req, res) => {
  try {
    // Get all tests and users for the dropdown
    const [tests] = await db.query("SELECT id, test_name FROM tests")
    const [users] = await db.query("SELECT id, username FROM users")

    res.render("testResult/addTestResult", {
      error: null,
      tests: tests,
      users: users,
    })
  } catch (err) {
    console.error(err)
    res.status(500).render("testResult/addTestResult", {
      error: "Failed to load form data",
      tests: [],
      users: [],
    })
  }
}

